/**
 * 
 */
package com.b510.scanFiles.client;

import java.util.Scanner;

import com.b510.scanFiles.dao.ScanFiles;
import com.b510.scanFiles.factory.ScanFilesFactory;
import com.b510.scanFiles.utils.CommonUtil;
import com.b510.scanFiles.utils.PrintUtil;

/**
 * The Client class,User can input some content in the console.<br>
 * and the system will monitoring the console and get the content and process it.
 * @author Hongten
 * @created Feb 12, 2014
 */
public class Client {

	private Scanner inputStreamScanner;
	private boolean controlFlag = false;

	public static void main(String[] args) {
		Client client = new Client();
		client.monitoringConsoleAndHandleContent();
	}

	public Client() {
		inputStreamScanner = new Scanner(System.in);
	}

	/**
	 * This is a monitor,which can monitoring the console and handle the input content.
	 */
	public void monitoringConsoleAndHandleContent() {
		PrintUtil.printInfo(CommonUtil.DESCRIPTION);
		try {
			while (!controlFlag && inputStreamScanner.hasNext()) {
				processingConsoleInput();
			}
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			closeScanner();
		}
	}

	private void closeScanner() {
		inputStreamScanner.close();
	}

	/**
	 * Processing the content that user inputed.
	 */
	private void processingConsoleInput() {
		String inputContent = inputStreamScanner.nextLine();
		if (!inputContent.isEmpty()) {
			controlFlag = exit(inputContent);
			if (!controlFlag) {
				notExit(inputContent);
			}
		}
	}

	/**
	 * When the user input the keyword <code>"exit"</code>(ignore case),then the system will be exit.
	 * @param inputContent
	 */
	private boolean exit(String inputContent) {
		if (CommonUtil.EXIT.equalsIgnoreCase(inputContent)) {
			controlFlag = true;
			systemExit();
		}
		return controlFlag;
	}

	/**
	 * System.exit(0);
	 */
	private void systemExit() {
		PrintUtil.printInfo(CommonUtil.EXIT_SYSTEM);
		System.exit(0);
	}

	/**
	 * different with the method "exit()"
	 * @param inputContent
	 */
	private void notExit(String inputContent) {
		String[] inputs = inputContent.split(CommonUtil.BLANK);
		if (null != inputs && inputs.length >= CommonUtil.TWO) {
			//the factory of the proxy
			ScanFiles factory = ScanFilesFactory.getInstance(inputs);
			if (CommonUtil.CD.equalsIgnoreCase(inputs[0])) {
				factory.handleCD(inputs);
			} else {
				factory.scan(inputs);
			}
		} else {
			PrintUtil.printInfo(CommonUtil.INCORRECT_INPUT_FORMAT);
		}
	}
}
