/**
 * 
 */
package com.b510.scanFiles.dao.impl;

import java.io.File;

import com.b510.scanFiles.dao.ScanFiles;
import com.b510.scanFiles.utils.CommonUtil;
import com.b510.scanFiles.utils.PrintUtil;

/**
 * the Delegate for the Scan Files.
 * @author Hongten
 * @created Feb 12, 2014
 */
public class ScanDelegate implements ScanFiles, Runnable {

	@SuppressWarnings("unused")
	private String[] inputs;
	private String path;
	private String suffix;
	private int targetCount;
	private int folderCount;
	private long startTime;

	public ScanDelegate(String[] inputs) {
		this.inputs = inputs;
	}

	public ScanDelegate(String path, String suffix) {
		this.path = path;
		this.suffix = suffix;
	}

	public void scanFiles(String[] inputs) {
		ScanDelegate delegate = new ScanDelegate(inputs[0], inputs[1]);
		new Thread(delegate).start();
	}

	/**
	 * scan the file(s) from the path,that user give.and return the count of the file(s).
	 */
	public int scan(String[] inputs) {
		int fileCount = 0;
		File file = new File(inputs[0]);
		if (!file.exists()) {
			PrintUtil.printInfo(CommonUtil.INCORRECT_PATH);
		} else {
			File[] subFile = file.listFiles();
			if (null == subFile || subFile.length == 0) {
				return fileCount;
			}
			for (int i = 0; i < subFile.length; i++) {
				if (subFile[i].isDirectory()) {
					folderCount++;
					fileCount += scan(new String[] { subFile[i].getAbsolutePath() });
				} else if (subFile[i].isFile()) {
					if (getPostfix(subFile[i].getName()).equalsIgnoreCase(suffix)) {
						PrintUtil.printInfo(CommonUtil.FIND_FILE + subFile[i].getAbsolutePath());
						targetCount++;
					}
					fileCount++;
				}
			}
		}
		return fileCount;
	}

	public void run() {
		startTime = System.currentTimeMillis();
		int num = scan(new String[] { path });
		printResult(num);
	}

	private void printResult(int num) {
		PrintUtil.printInfo(CommonUtil.BOUNDARY);
		PrintUtil.printInfo(CommonUtil.LEFT_BLANKETS + path + CommonUtil.CONTAINS);
		PrintUtil.printInfo(CommonUtil.FOLDERS + folderCount);
		PrintUtil.printInfo(CommonUtil.FILES + num);
		PrintUtil.printInfo(CommonUtil.TARGET + suffix + CommonUtil.TARGET_FILES + targetCount);
		PrintUtil.printInfo(CommonUtil.BOUNDARY);
		long entTime = System.currentTimeMillis();
		PrintUtil.printInfo(CommonUtil.SPEND + (entTime - startTime) + CommonUtil.MS);
	}

	/**
	 * handle the situation,e.g: "cd e:\"
	 */
	public void handleCD(String[] inputs) {
		File file = new File(inputs[1]);
		if (!file.exists()) {
			PrintUtil.printInfo(CommonUtil.INCORRECT_PATH);
		} else {
			File[] listFiles = file.listFiles();
			for (int i = 0; i < listFiles.length; i++) {
				PrintUtil.printInfo(listFiles[i].getName());
			}
			PrintUtil.printInfo(CommonUtil.BOUNDARY + "\n"+ CommonUtil.TOTAL + listFiles.length);
		}
	}

	/**
	 * get the suffix of a string,e.g : "test.txt"<br>
	 * and return the string is "txt".
	 * @param inputFilePath
	 * @return
	 */
	public String getPostfix(String inputFilePath) {
		return inputFilePath.substring(inputFilePath.lastIndexOf(CommonUtil.POINT) + 1);
	}
}
